Theory of Operation
===================

The following gives a brief overview of how VSG works.

.. toctree::
   :maxdepth: 2

   tokenizing
   tokens
   classifying
   internal_data_structure
   rule_selection
   rule_directory_structure
